API References
===============
.. warning::
   This project name has been renamed as **MolDF**, please go to its `documentation`_ for latest features.

.. _documentation: https://moldf.readthedocs.io/en/latest/

PDBx Reader
-------------------------

.. automodule:: pdbx2df.read_pdbx
   :members:
   :private-members:

PDB Reader
------------------------

.. automodule:: pdbx2df.read_pdb
   :members:
   :private-members:

MOL2 Reader
-------------------------

.. automodule:: pdbx2df.read_mol2
   :members:
   :private-members:

PDBDataFrame Class
-----------------------------
.. _PDBDataFrame:
.. automodule:: pdbx2df.pdb_dataframe
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:

PDBx Writer
--------------------------

.. automodule:: pdbx2df.write_pdbx
   :members:
   :private-members:

PDB Writer
-------------------------

.. automodule:: pdbx2df.write_pdb
   :members:
   :private-members:

MOL2 Writer
-------------------------

.. automodule:: pdbx2df.write_mol2
   :members:
   :private-members:

PDBx Line Splitter
--------------------------

.. autofunction:: pdbx2df.split_line
